@@ -191,7 +191,7 @@
     K <- ncol(X)  # number of covariates
 
     ## starting values and priors
-    beta.start <- coef.start(beta.start, K, formula, family=gaussian, data)
+    beta.start <- coef_start(beta.start, K, formula, family=gaussian, data)
     mvn.prior <- form.mvn.prior(b0, B0, K)
     b0 <- mvn.prior[[1]]
     B0 <- mvn.prior[[2]]
