@@ -128,15 +128,15 @@
 #'
 #' @export
 #'
-#' @author Ben Goodrich, \email{goodrich.ben@@gmail.com},
-#' \url{http://www.columbia.edu/~bg2382}
+#' @author Ben Goodrich, \email{goodrich.ben@gmail.com},
+#' \url{http://www.columbia.edu/~bg2382/}
 #'
 #' @seealso \code{\link[coda]{plot.mcmc}}, \code{\link[coda]{summary.mcmc}},
 #' \code{\link[survival]{survreg}}, \code{\link[MCMCpack]{MCMCregress}}
 #'
 #' @references Andrew D. Martin, Kevin M. Quinn, and Jong Hee Park. 2011.
 #' ``MCMCpack: Markov Chain Monte Carlo in R.'', \emph{Journal of Statistical
-#' Software}. 42(9): 1-21.  \url{http://www.jstatsoft.org/v42/i09/}.
+#' Software}. 42(9): 1-21.  \doi{10.18637/jss.v042.i09}.
 #'
 #' Daniel Pemstein, Kevin M. Quinn, and Andrew D. Martin.  2007.  \emph{Scythe
 #' Statistical Library 1.0.} \url{http://scythe.lsa.umich.edu}.
@@ -204,7 +204,7 @@ function(formula, data=NULL, below = 0.0, above = Inf,
     K <- ncol(X)  # number of covariates
 
     # starting values and priors
-    beta.start <- coef.start(beta.start, K, formula, family=gaussian, data)
+    beta.start <- coef_start(beta.start, K, formula, family=gaussian, data)
     mvn.prior <- form.mvn.prior(b0, B0, K)
     b0 <- mvn.prior[[1]]
     B0 <- mvn.prior[[2]]
