@@ -349,7 +349,7 @@ void HDPHMMpoissonReg_impl(rng<RNGTYPE>& stream,
           wip(nstate[j], 0, tot_rows - 1, 0) = selif(Sigma_plus_inv_sum, (s == (j + 1)) & (Y > 0));
         }
         Matrix<> Xwj(Xjp.rows(), k);
-        for (int h = 0; h<Xjp.rows(); ++h){
+        for (unsigned int h = 0; h<Xjp.rows(); ++h){
           Xwj(h, _) = Xjp(h,_)*wip[h];
         }
 
